@@ -140,7 +140,7 @@ Generated by <?= __PACKAGE__ ?>
 
 - [Routes](#routes)
 ? for (@$routes) {
-    - [<?= $_->title ?>](#<?= anchor(route => $_->title) ?>) - <?= $_->method ?> <?= $_->route ?>
+    - [<?= $_->title ?>](#<?= anchor(route => $_->title) ?>) - <?= methods($_->method) ?> <?= $_->route ?>
 ? }
 - [Resources](#resources)
 ? for (@$resources) {
